Learn R Programming

neuronorm (version 1.0.2)

coregistration_images: Create a vector of the corregistered images based on the available MRI images modalities.

Description

This function creates a vector of coregistered T2-weighted and/or FLAIR images for a patient. The vector contains a vector of length one for only one MRI modality (T2-weighted or FLAIR) or a vector of length two including both modalities (T2-weighted or FLAIR).

Usage

coregistration_images(vector)

Value

vector of coregistered images based on modalities available.

Arguments

vector

output object from the coregistration function.