This function creates a vector of imhomogeneity corrected images for a patient. The vector contains a vector of the length of the MRI modalities (T1-weighted, T2-weighted and/or FLAIR).
create_bias_list(modalities, bias_T1, list_corregister)vector of inhomogeneity corrected images based on modalities available.
vector of strings containing the modalities to be preprocessed. It must always contains the T1-weighted sequence scan.
bias image in NifTI format.
list of paths of corregisted images.