This function loads the MRI scans from a patient. It assumes that the MRI scans are contained in the same folder and refer to MRI modalities T1-weighted, T2-weighted and FLAIR. Only the first MRI scan that matched the modalities keywords ('T1','T2' or 'FLAIR') will be kept.
load_mri_patient(folder, modalities = c("T1", "T2", "FLAIR"))paths of MRI scans for a patient if they exist.
folder containing the MRI scans. The MRI scans should be in format NiFTI.
string or vector of strings with the MRI modalities to be considered. Should be at least one of T1, T2 or FLAIR. By default, all modalities are searched within the folder.