This function creates a vector of coregistered T2-weighted and/or FLAIR images for a patient. The vector contains a vector of length one for only one MRI modality (T2-weighted or FLAIR) or a vector of length two including both modalities (T2-weighted or FLAIR).
coregistration_images(vector)vector of coregistered images based on modalities available.
output object from the coregistration function.